@@ -30,6 +30,7 @@ class _GrowthFactor(Cmpt):
     r"""
     General class for a growth factor calculation.
     """
+
     supported_cosmos = (cosmology.LambdaCDM,)
 
     def __init__(self, cosmo, **model_parameters):
@@ -64,6 +65,7 @@ class GrowthFactor(_GrowthFactor):
     ----------
     .. [1] Lukic et. al., ApJ, 2007, http://adsabs.harvard.edu/abs/2007ApJ...671.1160L
     """
+
     _defaults = {"dlna": 0.01, "amin": 1e-8}
 
     def __init__(self, *args, **kwargs):
@@ -108,7 +110,7 @@ class GrowthFactor(_GrowthFactor):
             raise ValueError("Redshifts <0 not supported")
         if np.any(a < a_min):
             raise ValueError(
-                f"Cannot compute integral for z > {1/a_min - 1}. Set amin lower."
+                f"Cannot compute integral for z > {1 / a_min - 1}. Set amin lower."
             )
 
         return (self.integral(a) - self.integral(a_min)) * self.cosmo.efunc(z)
@@ -156,9 +158,9 @@ class GrowthFactor(_GrowthFactor):
         if not inverse:
             return self.growth_factor
 
-        z = np.sort(self._zvec)[::-1]
-        gf = self.growth_factor(z)
-        return _spline(gf, z)
+        gf = self.growth_factor(self._zvec)
+        idx = np.argsort(gf)
+        return _spline(gf[idx], self._zvec[idx])
 
     def growth_rate(self, z):
         """
@@ -200,6 +202,98 @@ class GrowthFactor(_GrowthFactor):
         )
 
 
+@_inherit
+class FromFile(GrowthFactor):
+    r"""
+    Import a growth factor from file.
+
+    .. note:: The file should be in the same format as output from CAMB,
+              or else in two-column ASCII format (z,d).
+
+    Parameters
+    ----------
+    \*\*model_parameters : unpack-dict
+        Parameters specific to this model. In this case, available
+        parameters are the following. To see their default values,
+        check the :attr:`_defaults` class attribute.
+
+        :fname: str
+            Location of the file to import.
+    """
+
+    supported_cosmos = (cosmology.LambdaCDM, cosmology.w0waCDM, cosmology.wCDM)
+    _defaults = {"dlna": 0.01, "amin": 1e-8, "fname": ""}
+
+    def growth_factor(self, z):
+        r"""
+        The growth factor, :math:`d(a) = D^+(a)/D^+(a=1)`.
+
+        Parameters
+        ----------
+        z : array_like
+            Redshift.
+
+        Returns
+        -------
+        gf : array_like
+            The growth factor at `z`.
+        """
+        G = np.genfromtxt(self.params["fname"])[:, [0, 1]].T
+
+        z_out = G[0, :]
+        d_out = G[1, :]
+        return _spline(z_out, d_out, k=1)(z)
+
+
+@_inherit
+class FromArray(FromFile):
+    r"""
+    Use a spline over a given array to define the transfer function
+
+    Parameters
+    ----------
+    \*\*model_parameters : unpack-dict
+        Parameters specific to this model. In this case, available
+        parameters are the following. To see their default values,
+        check the :attr:`_defaults` class attribute.
+
+        :z: array
+            Redshifts
+
+        :d: array
+            The growth factor at `z`.
+    """
+
+    supported_cosmos = (cosmology.LambdaCDM, cosmology.w0waCDM, cosmology.wCDM)
+    _defaults = {"dlna": 0.01, "amin": 1e-8, "z": None, "d": None}
+
+    def growth_factor(self, z):
+        r"""
+        The growth factor, :math:`d(a) = D^+(a)/D^+(a=1)`.
+
+        Parameters
+        ----------
+        z : array_like
+            Redshift.
+
+        Returns
+        -------
+        gf : array_like
+            The growth factor at `z`.
+        """
+        z_out = self.params["z"]
+        d_out = self.params["d"]
+
+        if z_out is None or d_out is None:
+            raise ValueError(
+                "You must supply an array for both z and d for this Growth model"
+            )
+        if len(z_out) != len(d_out):
+            raise ValueError("z and d must have same length")
+
+        return _spline(z_out, d_out, k=1)(z)
+
+
 @_inherit
 class GenMFGrowth(GrowthFactor):
     r"""
@@ -342,7 +436,7 @@ class Carroll1992(GrowthFactor):
 if HAVE_CAMB:
 
     @_inherit
-    class CambGrowth(_GrowthFactor):
+    class CambGrowth(GrowthFactor):
         """
         Uses CAMB to generate the growth factor, at k/h = 1.0. This class is recommended
         if the cosmology is not LambdaCDM (but instead wCDM), as it correctly deals with
@@ -357,33 +451,41 @@ if HAVE_CAMB:
 
             # Save the CAMB object properly for use
             # Set the cosmology
-            self.p = camb.CAMBparams()
+            self.p = self._get_camb_params(self.cosmo)
 
-            if self.cosmo.Ob0 is None:
+        @classmethod
+        def _get_camb_params(cls, cosmo: cosmology.FLRW) -> camb.CAMBparams:
+            p = camb.CAMBparams()
+
+            if cosmo.Ob0 is None:
                 raise ValueError(
                     "If using CAMB, the baryon density must be set explicitly in the cosmology."
                 )
 
-            if self.cosmo.Tcmb0.value == 0:
+            if cosmo.Tcmb0.value == 0:
                 raise ValueError(
                     "If using CAMB, the CMB temperature must be set explicitly in the cosmology."
                 )
 
-            self.p.set_cosmology(
-                H0=self.cosmo.H0.value,
-                ombh2=self.cosmo.Ob0 * self.cosmo.h**2,
-                omch2=(self.cosmo.Om0 - self.cosmo.Ob0) * self.cosmo.h**2,
-                omk=self.cosmo.Ok0,
-                nnu=self.cosmo.Neff,
-                standard_neutrino_neff=self.cosmo.Neff,
-                TCMB=self.cosmo.Tcmb0.value,
+            p.set_cosmology(
+                H0=cosmo.H0.value,
+                ombh2=cosmo.Ob0 * cosmo.h**2,
+                omch2=(cosmo.Om0 - cosmo.Ob0) * cosmo.h**2,
+                mnu=sum(cosmo.m_nu.value),
+                neutrino_hierarchy="degenerate",
+                omk=cosmo.Ok0,
+                nnu=cosmo.Neff,
+                standard_neutrino_neff=cosmo.Neff,
+                TCMB=cosmo.Tcmb0.value,
             )
 
-            self.p.WantTransfer = True
+            p.WantTransfer = True
 
             # Set the DE equation of state. We only support constant w.
-            if hasattr(self.cosmo, "w0"):
-                self.p.set_dark_energy(w=self.cosmo.w0)
+            if hasattr(cosmo, "w0"):
+                p.set_dark_energy(w=cosmo.w0)
+
+            return p
 
         @cached_property
         def _camb_transfers(self):
@@ -420,3 +522,18 @@ if HAVE_CAMB:
                 return growth[0]
             else:
                 return growth
+
+        def __getstate__(self):
+            dct = self.__dict__.copy()
+
+            # Can't pickle/copy CAMBparams or CAMBResults
+            del dct["p"]
+            if "_camb_transfers" in dct:
+                del dct["_camb_transfers"]
+
+            return dct
+
+        def __setstate__(self, state):
+            self.__dict__ = state
+
+            self.p = self._get_camb_params(self.cosmo)
