@@ -6,9 +6,10 @@ This code was heavily influenced by the `HaloFit` class from the
 and Michael Schneider (https://code.google.com/p/chomp/). It has
 been modified to improve its integration with this package.
 """
+
 import numpy as np
 import warnings
-from scipy.integrate import simps as _simps
+from scipy.integrate import simpson as _simps
 from scipy.interpolate import InterpolatedUnivariateSpline as _spline
 from scipy.optimize import minimize
 from typing import Tuple
@@ -42,11 +43,12 @@ def _get_spec(
     n_curv : float
         Curvature of the spectrum
     """
+
     # Initialize sigma spline
     def get_log_sigma2(lnr):
         R = np.exp(lnr)
         integrand = delta_k * np.exp(-((k * R) ** 2))
-        return np.log(_simps(integrand, np.log(k)))
+        return np.log(_simps(integrand, x=np.log(k)))
 
     def get_sigma_abs(lnr):
         return np.abs(get_log_sigma2(lnr))
@@ -75,7 +77,7 @@ def _get_spec(
     return knl, n_eff, n_curv
 
 
-def halofit(k, delta_k, sigma_8=None, z=0, cosmo=None, takahashi=True):
+def halofit(k, delta_k, *, sigma_8=None, z=0, cosmo=None, takahashi=True):
     """
     Implementation of HALOFIT (Smith+2003).
 
