@@ -5,6 +5,7 @@ This module contains a single class, `Transfer`, which provides methods to
 calculate the transfer function, matter power spectrum and several other
 related quantities.
 """
+
 import numpy as np
 
 from .._internals._cache import cached_quantity, parameter
@@ -55,7 +56,6 @@ class Transfer(cosmo.Cosmology):
         use_splined_growth=False,
         **kwargs,
     ):
-
         # Call Cosmology init
         super().__init__(**kwargs)
 
@@ -323,5 +323,5 @@ class Transfer(cosmo.Cosmology):
         .. math:: \Delta_k = \frac{k^3 P_{\rm nl}(k)}{2\pi^2}
         """
         return _hfit(
-            self.k, self.delta_k, self.sigma_8, self.z, self.cosmo, self.takahashi
+            self.k, self.delta_k, z=self.z, cosmo=self.cosmo, takahashi=self.takahashi
         )
