@@ -4,6 +4,7 @@ Various models for computing the transfer function.
 Note that these are not transfer function "frameworks". The framework is found
 in :mod:`hmf.transfer`.
 """
+
 import numpy as np
 import pickle
 import warnings
@@ -163,7 +164,7 @@ if HAVE_CAMB:
         _defaults = {
             "camb_params": None,
             "dark_energy_params": {},
-            "extrapolate_with_eh": False,
+            "extrapolate_with_eh": None,
             "kmax": None,
         }
 
@@ -194,7 +195,7 @@ if HAVE_CAMB:
                 if self.params["kmax"]:
                     self.params["camb_params"].Transfer.kmax = self.params["kmax"]
 
-            if self.cosmo.Ob0 is None:
+            if self.cosmo.Ob0 is None or self.cosmo.Ob0 == 0.0:
                 raise ValueError(
                     "To use CAMB, you must set the baryon density in the cosmology "
                     "explicitly."
@@ -209,8 +210,7 @@ if HAVE_CAMB:
             self.params["camb_params"].set_cosmology(
                 H0=self.cosmo.H0.value,
                 ombh2=self.cosmo.Ob0 * self.cosmo.h**2,
-                omch2=(self.cosmo.Om0 - self.cosmo.Ob0 - self.cosmo.Onu0)
-                * self.cosmo.h**2,
+                omch2=(self.cosmo.Om0 - self.cosmo.Ob0) * self.cosmo.h**2,
                 mnu=sum(self.cosmo.m_nu.value),
                 neutrino_hierarchy="degenerate",
                 omk=self.cosmo.Ok0,
@@ -228,6 +228,14 @@ if HAVE_CAMB:
                     w=self.cosmo.w0, wa=self.cosmo.wa
                 )
 
+            if self.params["extrapolate_with_eh"] is None:
+                warnings.warn(
+                    "'extrapolate_with_eh' was not set. Defaulting to True, which is "
+                    "different behaviour than versions <=3.4.4. This warning may be "
+                    "removed in v4.0. Silence it by setting extrapolate_with_eh explicitly."
+                )
+                self.params["extrapolate_with_eh"] = True
+
             if self.params["extrapolate_with_eh"]:
                 # Create an EH transfer to extrapolate to at high k.
                 self._eh = EH(self.cosmo)
@@ -462,9 +470,7 @@ class EH_BAO(TransferComponent):
         self.z_eq = 2.5e4 * self.Omh2 * self.theta_cmb ** (-4)  # really 1+z
         self.k_eq = 7.46e-2 * self.Omh2 * self.theta_cmb ** (-2)  # units Mpc^-1 (no h!)
 
-        self.z_drag_b1 = (
-            0.313 * self.Omh2**-0.419 * (1.0 + 0.607 * self.Omh2**0.674)
-        )
+        self.z_drag_b1 = 0.313 * self.Omh2**-0.419 * (1.0 + 0.607 * self.Omh2**0.674)
         self.z_drag_b2 = 0.238 * self.Omh2**0.223
         self.z_drag = (
             1291.0
@@ -686,6 +692,7 @@ class BBKS(TransferComponent):
     .. math:: \Gamma \rightarrow \Gamma
               \exp\left(-\Omega_{b,0}(1 + \sqrt{2h}/\Omega_{m,0})\right).
     """
+
     _defaults = {
         "a": 2.34,
         "b": 3.89,
@@ -760,6 +767,7 @@ class BondEfs(TransferComponent):
 
     .. math:: \alpha = \frac{0.3\times 0.75^2}{\Omega_{m,0} h^2}.
     """
+
     _defaults = {"a": 37.1, "b": 21.1, "c": 10.8, "nu": 1.12}
 
     def lnt(self, lnk):
