@@ -357,6 +357,11 @@ class MassFunction(transfer.Transfer):
         r"""The normalised mass variance at z=0 :math:`\sigma`."""
         return self._normalisation * self._unn_sigma0
 
+    @cached_quantity
+    def sigma8_z(self):
+        """sigma(8) at redshif z"""
+        return self.normalised_filter.sigma(8.0)
+
     @cached_quantity
     def radii(self):
         """The radii corresponding to the masses `m`.
@@ -389,6 +394,14 @@ class MassFunction(transfer.Transfer):
         """
         return (self.delta_c / self.sigma) ** 2
 
+    @cached_quantity
+    def nu_fn(self):
+        r"""
+        The parameter :math:`\nu = \left(\frac{\delta_c}{\sigma}\right)^2`, ``len=len(m)``
+        as a callable function
+        """
+        return spline(self.m, self.nu, k=5)
+
     @cached_quantity
     def mass_nonlinear(self):
         """The nonlinear mass, nu(Mstar) = 1."""
@@ -447,6 +460,14 @@ class MassFunction(transfer.Transfer):
         """
         return -3.0 * (2.0 * self._dlnsdlnm + 1.0)
 
+    @cached_quantity
+    def n_eff_at_collapse(self):
+        """
+        Effective spectral index at scale of halo radius at halo collapse.
+        """
+        fnc = spline(self.nu, self.n_eff)
+        return fnc(1)
+
     @cached_quantity
     def fsigma(self):
         r"""
@@ -463,7 +484,11 @@ class MassFunction(transfer.Transfer):
         dndm = self.fsigma * self.mean_density0 * np.abs(self._dlnsdlnm) / self.m**2
         if isinstance(self.hmf, ff.Behroozi):
             ngtm_tinker = self._gtm(dndm)
-            dndm = self.hmf._modify_dndm(self.m, dndm, self.z, ngtm_tinker)
+
+            # THe Behroozi paper corrections assume masses in Msun, not Msun/h
+            dndm = self.hmf._modify_dndm(
+                self.m * self.cosmo.h, dndm, self.z, ngtm_tinker
+            )
 
         # Alter the mass definition
         if (
