@@ -1,5 +1,6 @@
 import pytest
 
+import copy
 import numpy as np
 from astropy.cosmology import Planck13, w0waCDM
 
@@ -28,7 +29,6 @@ def test_gf(z, gf, genf):
 
 @pytest.mark.parametrize("z", np.arange(0, 8, 0.5))
 def test_gr(z, gf, genf):
-    gf.growth_rate(z), genf.growth_rate(z)
     assert np.isclose(gf.growth_rate(z), genf.growth_rate(z), rtol=1e-2 + z / 100.0)
 
 
@@ -75,3 +75,34 @@ def test_carroll(gf):
 
     z = np.arange(6)
     np.testing.assert_allclose(gf.growth_rate(z), cgf.growth_rate(z), rtol=0.05)
+
+
+def test_pickleability_of_cambgrowth():
+    gf = growth_factor.CambGrowth(Planck13)
+    gf_at_1 = gf.growth_factor(1.0)
+
+    gf2 = copy.deepcopy(gf)
+
+    assert gf2.growth_factor(1.0) == gf_at_1
+
+
+def test_from_file(datadir):
+    cosmo = w0waCDM(H0=70.0, Om0=0.3, Ode0=0.7, w0=-0.9, Ob0=0.05, Tcmb0=2.7)
+    gf = growth_factor.FromFile(
+        cosmo=cosmo, fname=f"{datadir}/growth_for_hmf_tests.dat"
+    )
+    data_in = np.genfromtxt(f"{datadir}/growth_for_hmf_tests.dat")[:, [0, 1]]
+    z = data_in[:, 0]
+    d = data_in[:, 1]
+
+    np.testing.assert_allclose(gf.growth_factor(z), d, rtol=0.05)
+
+
+def test_from_array(datadir):
+    cosmo = w0waCDM(H0=70.0, Om0=0.3, Ode0=0.7, w0=-0.9, Ob0=0.05, Tcmb0=2.7)
+    data_in = np.genfromtxt(f"{datadir}/growth_for_hmf_tests.dat")[:, [0, 1]]
+    z = data_in[:, 0]
+    d = data_in[:, 1]
+
+    gf = growth_factor.FromArray(cosmo=cosmo, z=z, d=d)
+    np.testing.assert_allclose(gf.growth_factor(z), d, rtol=0.05)
