@@ -1,5 +1,3 @@
-from pytest import raises
-
 import numpy as np
 from scipy.interpolate import InterpolatedUnivariateSpline as spline
 
@@ -7,8 +5,8 @@ from hmf.helpers.sample import dndm_from_sample, sample_mf
 
 
 def test_circular():
-    np.random.seed(1234)
-    m, h = sample_mf(1e5, 11, transfer_model="EH")
+    rng = np.random.default_rng(1234)
+    m, h = sample_mf(1e5, 11, transfer_model="EH", rng=rng)
     centres, hist = dndm_from_sample(m, 1e5 / h.ngtm[0])
 
     s = spline(np.log10(h.m), np.log10(h.dndm))
@@ -18,12 +16,9 @@ def test_circular():
 
 
 def test_mmax_big():
-    # raises ValueError because ngtm=0 exactly at m=18
-    # due to hard limit of integration in integrate_hmf.
-    np.random.seed(12345)
+    rng = np.random.default_rng(12345)
 
-    m, h = sample_mf(1e5, 11, transfer_model="EH", Mmax=18)
+    m, h = sample_mf(1e5, 11, transfer_model="EH", Mmax=18, rng=rng)
     # centres,hist = dndm_from_sample(m,1e5/h.ngtm[0])
     # print centres,hist
-    with raises(ValueError):
-        dndm_from_sample(m, 1e5 / h.ngtm[0])
+    dndm_from_sample(m, 1e5 / h.ngtm[0])
