@@ -2,20 +2,9 @@ import pytest
 
 import camb
 import numpy as np
-from astropy.cosmology import LambdaCDM, w0waCDM, wCDM
+from astropy.cosmology import FlatLambdaCDM, LambdaCDM, w0waCDM, wCDM
 
 from hmf.density_field.transfer import Transfer
-from hmf.density_field.transfer_models import EH_BAO
-
-# def rms(a):
-#     print(a)
-#     print("RMS: ", np.sqrt(np.mean(np.square(a))))
-#     return np.sqrt(np.mean(np.square(a)))
-
-#
-# def check_close(t, t2, fit):
-#     t.update(transfer_model=fit)
-#     assert np.mean(np.abs((t.power - t2.power) / t.power)) < 1
 
 
 @pytest.fixture
@@ -39,10 +28,24 @@ def test_updates(transfers, name, val):
     )
 
 
+def test_updates_from_file_array(datadir):
+    tdata = np.genfromtxt(f"{datadir}/transfer_for_hmf_tests.dat")
+    t = Transfer(
+        transfer_model="FromArray", transfer_params={"k": tdata[:, 0], "T": tdata[:, 1]}
+    )
+    t2 = Transfer(
+        transfer_model="FromArray", transfer_params={"k": tdata[:, 0], "T": tdata[:, 1]}
+    )
+    t2.update(transfer_params={"k": tdata[::2, 0], "T": tdata[::2, 1]})
+    # This test for both FromArray transfer model and caching of dictionaries
+    assert (
+        np.mean(np.abs((t.power - t2.power) / t.power)) < 1
+        and np.mean(np.abs((t.power - t2.power) / t.power)) > 1e-6
+    )
+
+
 def test_halofit():
     t = Transfer(lnk_min=-20, lnk_max=20, dlnk=0.05, transfer_model="EH")
-    print(EH_BAO._defaults)
-    print("in test_transfer, params are: ", t.transfer_params)
     assert np.isclose(t.power[0], t.nonlinear_power[0])
     assert 5 * t.power[-1] < t.nonlinear_power[-1]
 
@@ -91,6 +94,67 @@ def test_camb_extrapolation():
     assert np.isclose(eh[-1], camb[-1], rtol=1e-1)
 
 
+def test_camb_neutrinos():
+    # Correct parameter settings:
+    cosmo_model = FlatLambdaCDM(
+        Om0=0.3, H0=70.0, Ob0=0.05, m_nu=[0, 0, 0.06], Tcmb0=2.7255
+    )
+
+    t_nu = Transfer(
+        cosmo_model=cosmo_model,
+        sigma_8=0.8,
+        n=1,
+        transfer_model="CAMB",
+        transfer_params={"extrapolate_with_eh": True},
+        lnk_min=np.log(1e-11),
+        lnk_max=np.log(1e11),
+    )
+
+    pars = camb.CAMBparams(
+        DoLensing=False,
+        Want_CMB=False,
+        Want_CMB_lensing=False,
+        WantCls=False,
+        WantDerivedParameters=False,
+        WantTransfer=True,
+    )
+    pars.Transfer.high_precision = False
+    pars.Transfer.k_per_logint = 0
+    pars.set_cosmology(
+        H0=cosmo_model.H0.value,
+        ombh2=cosmo_model.Ob0 * cosmo_model.h**2,
+        omch2=(cosmo_model.Om0 - cosmo_model.Ob0) * cosmo_model.h**2,
+        mnu=sum(cosmo_model.m_nu.value),
+        neutrino_hierarchy="degenerate",
+        omk=cosmo_model.Ok0,
+        nnu=cosmo_model.Neff,
+        standard_neutrino_neff=cosmo_model.Neff,
+        TCMB=cosmo_model.Tcmb0.value,
+    )
+
+    t_nu_camb = t_nu.clone()
+    t_nu_camb.transfer.params["camb_params"] = pars
+
+    k = np.logspace(-4, 2, 10)
+    hmf_t = t_nu.transfer.lnt(np.log(k))[0]
+    camb_t = t_nu_camb.transfer.lnt(np.log(k))[0]
+
+    diff = np.abs((camb_t - hmf_t) / camb_t)
+
+    camb_cosmo = camb.get_background(t_nu.transfer.params["camb_params"])
+    sum_omega_astropy = (
+        t_nu.cosmo_model.Odm0 + t_nu.cosmo_model.Ob0 + t_nu.cosmo_model.Onu0
+    )
+    sum_omega_camb = (
+        camb_cosmo.get_Omega("tot")
+        - camb_cosmo.get_Omega("photon")
+        - camb_cosmo.omega_de
+    )
+
+    assert diff <= 1e-3
+    assert np.isclose(sum_omega_astropy, sum_omega_camb, rtol=1e-2)
+
+
 def test_setting_kmax():
     t = Transfer(
         transfer_params={"extrapolate_with_eh": True, "kmax": 1.0},
@@ -109,6 +173,7 @@ def test_camb_w0wa():
         cosmo_model=w0waCDM(
             Om0=0.3, Ode0=0.7, w0=-1, wa=0.03, Ob0=0.05, H0=70.0, Tcmb0=2.7
         ),
+        transfer_params={"extrapolate_with_eh": True},
     )
     assert t.transfer_function.shape == t.k.shape
 
@@ -118,11 +183,13 @@ def test_camb_wCDM():
     t = Transfer(
         transfer_model="CAMB",
         cosmo_model=wCDM(Om0=0.3, Ode0=0.7, w0=-1, Ob0=0.05, H0=70.0, Tcmb0=2.7),
+        transfer_params={"extrapolate_with_eh": True},
     )
 
     t2 = Transfer(
         transfer_model="CAMB",
         cosmo_model=LambdaCDM(Om0=0.3, Ode0=0.7, Ob0=0.05, H0=70.0, Tcmb0=2.7),
+        transfer_params={"extrapolate_with_eh": True},
     )
     np.testing.assert_array_almost_equal(t.transfer_function, t2.transfer_function)
 
